@@ -1,5 +1,5 @@
 from netbox.api.serializers import ValidatedModelSerializer, WritableNestedSerializer, OrganizationalModelSerializer, \
-    PrimaryModelSerializer, NestedGroupModelSerializer
+    PrimaryModelSerializer, NestedGroupModelSerializer, BulkOperationSerializer
 
 
 class PluginValidatedModelSerializer(ValidatedModelSerializer):
@@ -31,4 +31,4 @@ class PluginNestedGroupModelSerializer(NestedGroupModelSerializer):
 
 
 class PluginBulkOperationSerializer(BulkOperationSerializer):
-    pass
\ No newline at end of file
+    pass
